@@ -25,9 +25,6 @@ if getattr(settings, 'TEST_MODE', False) or os.getenv('TRAVIS_MODE', False):
 else:
     import milestones.resources as remote
 """
-from __future__ import absolute_import, unicode_literals
-
-import six
 
 from . import exceptions
 from . import models as internal
@@ -199,7 +196,7 @@ def fetch_milestones(milestone):
         ))
     if milestone_obj.namespace:
         return serializers.serialize_milestones(internal.Milestone.objects.filter(
-            namespace=six.text_type(milestone_obj.namespace),
+            namespace=str(milestone_obj.namespace),
             active=True
         ))
 
@@ -223,7 +220,7 @@ def create_course_milestone(course_key, relationship, milestone):
     milestone_obj = serializers.deserialize_milestone(milestone)
     try:
         relationship = internal.CourseMilestone.objects.get(
-            course_id=six.text_type(course_key),
+            course_id=str(course_key),
             milestone=milestone_obj,
             milestone_relationship_type=relationship_type
         )
@@ -232,7 +229,7 @@ def create_course_milestone(course_key, relationship, milestone):
             _activate_record(relationship)
     except internal.CourseMilestone.DoesNotExist:
         internal.CourseMilestone.objects.create(
-            course_id=six.text_type(course_key),
+            course_id=str(course_key),
             milestone=milestone_obj,
             milestone_relationship_type=relationship_type,
             active=True
@@ -246,7 +243,7 @@ def delete_course_milestone(course_key, milestone):
     """
     try:
         relationship = internal.CourseMilestone.objects.get(
-            course_id=six.text_type(course_key),
+            course_id=str(course_key),
             milestone=milestone['id'],
             active=True,
         )
@@ -297,8 +294,8 @@ def create_course_content_milestone(course_key, content_key, relationship, miles
     requirements = serializers.serialize_requirements(requirements)
     try:
         relationship = internal.CourseContentMilestone.objects.get(
-            course_id=six.text_type(course_key),
-            content_id=six.text_type(content_key),
+            course_id=str(course_key),
+            content_id=str(content_key),
             milestone=milestone_obj,
             milestone_relationship_type=relationship_type
         )
@@ -312,8 +309,8 @@ def create_course_content_milestone(course_key, content_key, relationship, miles
             relationship.save()
     except internal.CourseContentMilestone.DoesNotExist:
         internal.CourseContentMilestone.objects.create(
-            course_id=six.text_type(course_key),
-            content_id=six.text_type(content_key),
+            course_id=str(course_key),
+            content_id=str(content_key),
             milestone=milestone_obj,
             milestone_relationship_type=relationship_type,
             requirements=requirements,
@@ -328,8 +325,8 @@ def delete_course_content_milestone(course_key, content_key, milestone):
     """
     try:
         relationship = internal.CourseContentMilestone.objects.get(
-            course_id=six.text_type(course_key),
-            content_id=six.text_type(content_key),
+            course_id=str(course_key),
+            content_id=str(content_key),
             milestone=milestone['id'],
             active=True,
         )
@@ -351,10 +348,10 @@ def fetch_course_content_milestones(content_key=None, course_key=None, relations
     ).select_related('milestone')
 
     if course_key is not None:
-        queryset = queryset.filter(course_id=six.text_type(course_key))
+        queryset = queryset.filter(course_id=str(course_key))
 
     if content_key is not None:
-        queryset = queryset.filter(content_id=six.text_type(content_key))
+        queryset = queryset.filter(content_id=str(content_key))
 
     if relationship is not None:
         mrt = _get_milestone_relationship_type(relationship)
@@ -477,7 +474,7 @@ def delete_content_references(content_key):
     Supports the 'delete entrance exam' Studio use case, when Milestones is enabled
     """
     [_inactivate_record(record) for record in internal.CourseContentMilestone.objects.filter(
-        content_id=six.text_type(content_key),
+        content_id=str(content_key),
         active=True
     )]
 
@@ -487,11 +484,11 @@ def delete_course_references(course_key):
     Inactivates references to course keys within this app (ref: receivers.py and api.py)
     """
     [_inactivate_record(record) for record in internal.CourseMilestone.objects.filter(
-        course_id=six.text_type(course_key),
+        course_id=str(course_key),
         active=True
     )]
 
     [_inactivate_record(record) for record in internal.CourseContentMilestone.objects.filter(
-        course_id=six.text_type(course_key),
+        course_id=str(course_key),
         active=True
     )]
